@@ -1739,6 +1739,12 @@ static inline
 int snd_pcm_sw_params_set_avail_min(snd_pcm_t *pcm, snd_pcm_sw_params_t *params,
 				    snd_pcm_uframes_t val)
 {
+	/* Fix avail_min if it's below period size.  The period_size
+	 * defines the minimal wake-up timing accuracy, so it doesn't
+	 * make sense to set below that.
+	 */
+	if (val < pcm->period_size)
+		val = pcm->period_size;
 	params->avail_min = val;
 	return 0;
 }
@@ -1995,8 +2001,8 @@ void snd_pcm_info_set_stream(snd_pcm_info_t *obj, snd_pcm_stream_t val)
 }
 
 static inline
-int snd_hw_htimestamp(snd_pcm_t *pcm, snd_pcm_uframes_t *avail,
-		      snd_htimestamp_t *tstamp)
+int snd_pcm_htimestamp(snd_pcm_t *pcm, snd_pcm_uframes_t *avail,
+		       snd_htimestamp_t *tstamp)
 {
 	*avail = snd_pcm_avail_update(pcm);
 	*tstamp = pcm->mmap_status->tstamp;
